/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsAsciiToUnicode.h"

//----------------------------------------------------------------------
// Global functions and data [declaration]

// use iso-8859-1 decoder to interpret us-ascii. Some websites are mistakenly 
// labeled as us-ascii for iso-8859-1. Be generous here should be fine. 

static const PRUint16 g_utMappingTable[] = {
// this part is copied from ../src/cp1252.ut
/*========================================================
  This is a Generated file. Please don't edit it.

  The tool which used to generate this file is called fromu.
  If you have any problem of this file. Please contact 
  Netscape Client International Team or 
  ftang@netscape <Frank Tang> 

              Table in Debug form 
Begin of Item 0000
 Format 0
  srcBegin = 0000
  srcEnd = 007F
  destBegin = 0000
End of Item 0000 

Begin of Item 0001
 Format 0
  srcBegin = 00A0
  srcEnd = 00FF
  destBegin = 00A0
End of Item 0001 

Begin of Item 0002
 Format 1
  srcBegin = 0080
  srcEnd = 009F
  mappingOffset = 0000
 Mapping  = 
  20AC 0081 201A 0192 201E 2026 2020 2021 
  02C6 2030 0160 2039 0152 008D 017D 008F 
  0090 2018 2019 201C 201D 2022 2013 2014 
  02DC 2122 0161 203A 0153 009D 017E 0178 
End of Item 0002 

========================================================*/
/* Offset=0x0000  ItemOfList */
  0x0003,
/*-------------------------------------------------------*/
/* Offset=0x0001  offsetToFormatArray */
  0x0004,
/*-------------------------------------------------------*/
/* Offset=0x0002  offsetToMapCellArray */ 
  0x0005,
/*-------------------------------------------------------*/
/* Offset=0x0003  offsetToMappingTable */ 
  0x000E,
/*-------------------------------------------------------*/
/*       Offset=0x0004   Start of Format Array */ 
/*	Total of Format 0 : 0x0002			 */
/*	Total of Format 1 : 0x0001			 */
/*	Total of Format 2 : 0x0000			 */
/*	Total of Format 3 : 0x0000			 */

0x0100, 
/*-------------------------------------------------------*/
/*       Offset=0x0005   Start of MapCell Array */ 
/* 0000 */    0x0000, 0x007F, 0x0000, 
/* 0001 */    0x00A0, 0x00FF, 0x00A0, 
/* 0002 */    0x0080, 0x009F, 0x0000, 
/*-------------------------------------------------------*/
/*       Offset=0x000E   Start of MappingTable */ 

/* 0000 */    0x20AC, 0x0081, 0x201A, 0x0192, 0x201E, 0x2026, 0x2020, 0x2021, 
/* 0008 */    0x02C6, 0x2030, 0x0160, 0x2039, 0x0152, 0x008D, 0x017D, 0x008F, 
/* 0010 */    0x0090, 0x2018, 0x2019, 0x201C, 0x201D, 0x2022, 0x2013, 0x2014, 
/* 0018 */    0x02DC, 0x2122, 0x0161, 0x203A, 0x0153, 0x009D, 0x017E, 0x0178, 
/*	End of table Total Length = 0x002E * 2 */
};

static const PRInt16 g_utShiftTable[] =  {
  0, u1ByteCharset ,
  ShiftCell(0,0,0,0,0,0,0,0)
};

//----------------------------------------------------------------------
// Class nsAsciiToUnicode [implementation]

nsAsciiToUnicode::nsAsciiToUnicode() 
: nsOneByteDecoderSupport((uShiftTable*) &g_utShiftTable, 
                          (uMappingTable*) &g_utMappingTable)
{
}
